@@ -1017,6 +1017,28 @@ def build_parser():
             Default is 0.
         """,
     )
+    transport.add_argument(
+        "--stream-segmented-queue-deadline",
+        metavar="FACTOR",
+        type=num(float, ge=0.0),
+        help="""
+            A multiplication factor of the time frame in which new segments must be queued in order to prevent playback issues
+            due to lack of video/audio data. If this segment-queue-deadline has not been met, the stream will be stopped early.
+
+            The intention of this segment-queue-deadline is to be able to stop early when the end of a stream is not announced
+            by the server, so Streamlink doesn't have to wait until a buffer read-timeout occurs. See --stream-timeout.
+
+            The base time this multiplication factor is applied to depends on the specific
+            stream implementation and the respective values returned by the streaming server.
+            This deadline check is done after trying to fetch new data.
+
+            Set to ``0`` to disable.
+
+            Default is 3.0.
+
+            By default, wait three times as long for new segments to be made available than the server's advertised time frame.
+        """,
+    )
     transport.add_argument(
         "--stream-timeout",
         type=num(float, gt=0),
@@ -1094,19 +1116,9 @@ def build_parser():
     transport_hls.add_argument(
         "--hls-segment-queue-threshold",
         metavar="FACTOR",
-        type=num(float, ge=0),
+        type=num(float, ge=0.0),
         help="""
-            The multiplication factor of the HLS playlist's target duration after which the stream will be stopped early
-            if no new segments were queued after refreshing the playlist (multiple times). The target duration defines the
-            maximum duration a single segment can have, meaning new segments must be available during this time frame,
-            otherwise playback issues can occur.
-
-            The intention of this queue threshold is to be able to stop early when the end of a stream doesn't get
-            announced by the server, so Streamlink doesn't have to wait until a read-timeout occurs. See --stream-timeout.
-
-            Set to ``0`` to disable.
-
-            Default is 3.
+            Deprecated in favor of --stream-segmented-queue-deadline.
         """,
     )
     transport_hls.add_argument(
@@ -1521,19 +1533,20 @@ _ARGUMENT_TO_SESSIONOPTION: list[tuple[str, str, Callable[[Any], Any] | None]] =
     ("http_timeout", "http-timeout", None),
     # stream transport arguments
     ("hls_duration", "hls-duration", None),  # deprecated options must come first
+    ("hls_segment_queue_threshold", "hls-segment-queue-threshold", None),  # deprecated options must come first
     ("ringbuffer_size", "ringbuffer-size", None),
     ("mux_subtitles", "mux-subtitles", None),
     ("stream_segment_attempts", "stream-segment-attempts", None),
     ("stream_segment_threads", "stream-segment-threads", None),
     ("stream_segment_timeout", "stream-segment-timeout", None),
     ("stream_segmented_duration", "stream-segmented-duration", None),
+    ("stream_segmented_queue_deadline", "stream-segmented-queue-deadline", None),
     ("stream_timeout", "stream-timeout", None),
     ("hls_live_edge", "hls-live-edge", None),
     ("hls_live_restart", "hls-live-restart", None),
     ("hls_start_offset", "hls-start-offset", None),
     ("hls_playlist_reload_attempts", "hls-playlist-reload-attempts", None),
     ("hls_playlist_reload_time", "hls-playlist-reload-time", None),
-    ("hls_segment_queue_threshold", "hls-segment-queue-threshold", None),
     ("hls_segment_stream_data", "hls-segment-stream-data", None),
     ("hls_segment_ignore_names", "hls-segment-ignore-names", None),
     ("hls_segment_key_uri", "hls-segment-key-uri", None),
